==> firebase_repository-1.0.59.tar.gz: lib/src/entities/movrodeo_entity.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:equatable/equatable.dart';

class MovrodeoEntity extends Equatable {
  final String uuid;
  final int cabezas;
  final String concepto;
  final int desbaste;
  final String detalle;
  final String destino;
  final DateTime fecha;
  final int kilos;
  final int precio;
  final String tropaUuid;

  MovrodeoEntity(
      this.uuid,
      this.cabezas,
      this.concepto,
      this.desbaste,
      this.detalle,
      this.destino,
      this.fecha,
      this.kilos,
      this.precio,
      this.tropaUuid);

  Map<String, Object> toJson() {
    return {
      'cabezas': this.cabezas,
      'concepto': this.concepto,
      'desbaste': this.desbaste,
      'detalle': this.detalle,
      'destino': this.destino,
      'fecha': this.fecha,
      'kilos': this.kilos,
      'precio': this.precio,
      'tropaUuid': this.tropaUuid
    };
  }

  @override
  String toString() {
    return 'MovrodeoEntity{uuid: $uuid, cabezas: $cabezas, concepto: $concepto, desbaste: $desbaste, detalle: $detalle, destino: $destino, fecha: $fecha, kilos: $kilos, precio: $precio, tropaUuid: $tropaUuid}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      super == other &&
          other is MovrodeoEntity &&
          runtimeType == other.runtimeType &&
          uuid == other.uuid &&
          cabezas == other.cabezas &&
          concepto == other.concepto &&
          desbaste == other.desbaste &&
          detalle == other.detalle &&
          destino == other.destino &&
          fecha == other.fecha &&
          kilos == other.kilos &&
          precio == other.precio &&
          tropaUuid == other.tropaUuid;

  @override
  int get hashCode =>
      super.hashCode ^
      uuid.hashCode ^
      cabezas.hashCode ^
      concepto.hashCode ^
      desbaste.hashCode ^
      detalle.hashCode ^
      destino.hashCode ^
      fecha.hashCode ^
      kilos.hashCode ^
      precio.hashCode ^
      tropaUuid.hashCode;

  MovrodeoEntity.fromJson(Map<String, Object> json)
      : uuid = json['uuid'],
        cabezas = json['cabezas'],
        concepto = json['concepto'],
        desbaste = json['desbaste'],
        detalle = json['detalle'],
        destino = json['destino'],
        fecha = json['fecha'],
        kilos = json['kilos'],
        precio = json['precio'],
        tropaUuid = json['tropaUuid'];

  MovrodeoEntity.fromSnapshot(DocumentSnapshot snapshot)
      : uuid = snapshot.documentID,
        cabezas = snapshot.data['cabezas'],
        concepto = snapshot.data['concepto'],
        desbaste = snapshot.data['desbaste'].runtimeType != int
            ? int.parse(snapshot.data['desbaste'].toString())
            : snapshot.data['desbaste'],
        detalle = snapshot.data['detalle'],
        destino = snapshot.data['destino'],
        fecha = snapshot.data['fecha'] != null
            ? (snapshot.data['fecha'] is int ||
                    snapshot.data['fecha'] is double)
                ? DateTime.fromMillisecondsSinceEpoch(
                    snapshot.data['fecha'].round().toInt())
                : snapshot.data['fecha'].toDate()
            : null,
        kilos = snapshot.data['kilos'].runtimeType != int
            ? int.parse(snapshot.data['kilos'].toString())
            : snapshot.data['kilos'],
        precio = snapshot.data['precio'].runtimeType != int
            ? int.parse(snapshot.data['precio'].toString())
            : snapshot.data['precio'],
        tropaUuid = snapshot.data['rodeo'];

  Map<String, Object> toDocument() {
    return {
      'cabezas': this.cabezas,
      'concepto': this.concepto,
      'desbaste': this.desbaste,
      'detalle': this.detalle,
      'destino': this.destino,
      'fecha': this.fecha,
      'kilos': this.kilos,
      'precio': this.precio,
      'rodeo': this.tropaUuid
    };
  }
}

==> firebase_repository-1.0.62.tar.gz: lib/src/entities/movrodeo_entity.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:equatable/equatable.dart';

class MovrodeoEntity extends Equatable {
  final String uuid;
  final int cabezas;
  final String concepto;
  final int desbaste;
  final String detalle;
  final String destino;
  final DateTime fecha;
  final int kilos;
  final int precio;
  final String tropaUuid;

  MovrodeoEntity(
      this.uuid,
      this.cabezas,
      this.concepto,
      this.desbaste,
      this.detalle,
      this.destino,
      this.fecha,
      this.kilos,
      this.precio,
      this.tropaUuid);

  Map<String, Object> toJson() {
    return {
      'cabezas': this.cabezas,
      'concepto': this.concepto,
      'desbaste': this.desbaste,
      'detalle': this.detalle,
      'destino': this.destino,
      'fecha': this.fecha,
      'kilos': this.kilos,
      'precio': this.precio,
      'tropaUuid': this.tropaUuid
    };
  }

  @override
  String toString() {
    return 'MovrodeoEntity{uuid: $uuid, cabezas: $cabezas, concepto: $concepto, desbaste: $desbaste, detalle: $detalle, destino: $destino, fecha: $fecha, kilos: $kilos, precio: $precio, tropaUuid: $tropaUuid}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      super == other &&
          other is MovrodeoEntity &&
          runtimeType == other.runtimeType &&
          uuid == other.uuid &&
          cabezas == other.cabezas &&
          concepto == other.concepto &&
          desbaste == other.desbaste &&
          detalle == other.detalle &&
          destino == other.destino &&
          fecha == other.fecha &&
          kilos == other.kilos &&
          precio == other.precio &&
          tropaUuid == other.tropaUuid;

  @override
  int get hashCode =>
      super.hashCode ^
      uuid.hashCode ^
      cabezas.hashCode ^
      concepto.hashCode ^
      desbaste.hashCode ^
      detalle.hashCode ^
      destino.hashCode ^
      fecha.hashCode ^
      kilos.hashCode ^
      precio.hashCode ^
      tropaUuid.hashCode;

  MovrodeoEntity.fromJson(Map<String, Object> json)
      : uuid = json['uuid'],
        cabezas = json['cabezas'],
        concepto = json['concepto'],
        desbaste = json['desbaste'],
        detalle = json['detalle'],
        destino = json['destino'],
        fecha = json['fecha'],
        kilos = json['kilos'],
        precio = json['precio'],
        tropaUuid = json['tropaUuid'];

  MovrodeoEntity.fromSnapshot(DocumentSnapshot snapshot)
      : uuid = snapshot.documentID,
        cabezas = snapshot.data['cabezas'],
        concepto = snapshot.data['concepto'],
        desbaste = snapshot.data['desbaste'] != null ? snapshot.data['desbaste'].runtimeType != int
            ? int.parse(snapshot.data['desbaste'].toString())
            : snapshot.data['desbaste'] : null,
        detalle = snapshot.data['detalle'],
        destino = snapshot.data['destino'],
        fecha = snapshot.data['fecha'] != null
            ? (snapshot.data['fecha'] is int ||
                    snapshot.data['fecha'] is double)
                ? DateTime.fromMillisecondsSinceEpoch(
                    snapshot.data['fecha'].round().toInt())
                : snapshot.data['fecha'].toDate()
            : null,
        kilos = snapshot.data['kilos'].runtimeType != int
            ? int.parse(snapshot.data['kilos'].toString())
            : snapshot.data['kilos'],
        precio = snapshot.data['precio'].runtimeType != int
            ? int.parse(snapshot.data['precio'].toString())
            : snapshot.data['precio'],
        tropaUuid = snapshot.data['rodeo'];

  Map<String, Object> toDocument() {
    return {
      'cabezas': this.cabezas,
      'concepto': this.concepto,
      'desbaste': this.desbaste,
      'detalle': this.detalle,
      'destino': this.destino,
      'fecha': this.fecha,
      'kilos': this.kilos,
      'precio': this.precio,
      'rodeo': this.tropaUuid
    };
  }
}
